@@ -1,7 +1,7 @@
 # -*- mode: Perl -*-
 package MRTG_lib;
 ###################################################################
-# MRTG 2.16.2  Support library MRTG_lib.pm
+# MRTG 2.16.3  Support library MRTG_lib.pm
 ###################################################################
 # Created by Tobias Oetiker <tobi@oetiker.ch>
 #            and Dave Rand <dlr@bungi.com>
@@ -198,7 +198,7 @@ $VERSION = 2.100016;
        [sub{1}, sub{"Internal Error"}], #what ever the user chooses.
 
        'clonedirectory[]' =>
-       [sub{1}, sub{"Internal Error"}], #what ever the user chooses.
+       [sub{($_[0] =~ /[^,]\s*$/)}, sub{"$_[0] with comma must have the second parameter"}], 
 
        'pagetop[]' => 
        [sub{1}, sub{"Internal Error"}], #what ever the user chooses.
@@ -215,6 +215,15 @@ $VERSION = 2.100016;
        'rrdrowcount[]' => 
        [sub{1}, sub{"Internal Error"}], #what ever the user chooses.
 
+       'rrdrowcount30m[]' =>
+       [sub{1}, sub{"Internal Error"}], #what ever the user chooses.
+
+       'rrdrowcount2h[]' =>
+       [sub{1}, sub{"Internal Error"}], #what ever the user chooses.
+
+       'rrdrowcount1d[]' =>
+       [sub{1}, sub{"Internal Error"}], #what ever the user chooses.
+
        'rrdhwrras[]' =>
        [sub{$_[0] =~ /^RRA:(HWPREDICT|SEASONAL|DEVPREDICT|DEVSEASONAL|FAILURES):\S+(\s+RRA:(HWPREDICT|SEASONAL|DEVPREDICT|DEVSEASONAL|FAILURES):\S+)*$/},
         sub{"This does not look like rrdtool HW RRAs. Check the rrdcreate manual page for inspiration. ($_[0])"}],
@@ -1803,7 +1812,7 @@ sub log2rrd ($$$) {
                            if (defined $$rcfg{'options'}{'perhour'}{$router});    
                        $rate{$t}{$s}/=60
                            if (defined $$rcfg{'options'}{'perminute'}{$router});
- 	  	       push @{$store{$t}{$s}}, int($rate{$t}{$s});
+ 	  	       push @{$store{$t}{$s}}, $rate{$t}{$s};
 		    }
 		    $mark{$s} -= $s;
 		    $rate{maxin}{$s} = 0;
