@@ -1,5 +1,5 @@
 /*
- MRTG 2.16.2  -- Rateup
+ MRTG 2.16.3  -- Rateup
  *********************
 
  Rateup is a fast add-on to the great MRTG Traffic monitor.  It makes
@@ -83,7 +83,7 @@
 #include <gd.h>
 #include <gdfonts.h>
 
-char *VERSION = "2.16.2";
+char *VERSION = "2.16.3";
 char *program, *router, *routerpath;
 int histvalid;
 
@@ -1514,7 +1514,7 @@ update (in, out, abs_max, absupdate)
 
 
 
-  if (inrate < 0 || (unsigned) inrate > abs_max)
+  if (inrate < 0 ||  inrate > abs_max)
     {
       if (options & OPTION_UNKNASZERO)
 	{
@@ -1525,7 +1525,7 @@ update (in, out, abs_max, absupdate)
 	  inrate = history[0].in;	/* Sync by using last value */
 	}
     }
-  if (outrate < 0 || (unsigned) outrate > abs_max)
+  if (outrate < 0 || outrate > abs_max)
     {
       if (options & OPTION_UNKNASZERO)
 	{
